from django.db import models
from django.utils import timezone


class Testimonial(models.Model):

    text = models.TextField()
    author = models.CharField(max_length=100)
    affiliation = models.CharField(max_length=100, blank=True)
    added = models.DateTimeField(default=timezone.now)
    active = models.BooleanField(default=False)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-04-13 11:25
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Testimonial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField()),
                ('author', models.CharField(max_length=100)),
                ('affiliation', models.CharField(blank=True, max_length=100)),
                ('added', models.DateTimeField(default=django.utils.timezone.now)),
                ('active', models.BooleanField(default=False)),
            ],
        ),
    ]



from django.test import TestCase

from ..models import Testimonial
from ..templatetags.pinax_testimonials_tags import \
    random_testimonial as random_testimonial_tag
from ..templatetags.pinax_testimonials_tags import \
    random_testimonials as random_testimonials_tag
from ..templatetags.pinax_testimonials_tags import \
    testimonials as testimonials_tag


class TestTags(TestCase):

    def setUp(self):
        self.first = Testimonial.objects.create(
            text="first text",
            author="first",
            active=True
        )
        self.second = Testimonial.objects.create(
            text="second text",
            author="second",
            active=True
        )
        # Create an inactive testimonial which should not get returned.
        self.inactive = Testimonial.objects.create(
            text="inactive text",
            author="inactive",
            # active=False  # set False by default
        )
        self.third = Testimonial.objects.create(
            text="third text",
            author="third",
            active=True
        )

    def test_random_testimonials(self):
        """
        Ensure tag returns all active testimonials.
        """
        testimonials = random_testimonials_tag(3)
        self.assertSetEqual(set(testimonials), set([self.first, self.second, self.third]))

    def test_random_testimonial(self):
        """
        Ensure we receive one Testimonial instance.
        """
        testimonial = random_testimonial_tag()
        self.assertTrue(isinstance(testimonial, Testimonial))

    def test_testimonials(self):
        """
        Ensure tag returns all active testimonials in reverse creation order.
        """
        testimonials = testimonials_tag(3)
        self.assertSequenceEqual(testimonials, [self.third, self.second, self.first])



from django.contrib import admin

from .models import Testimonial


def make_active(modeladmin, request, queryset):
    queryset.update(active=True)


make_active.short_description = "Mark as Active"


def make_inactive(modeladmin, request, queryset):
    queryset.update(active=False)


make_inactive.short_description = "Mark as Inactive"


class TestimonialAdmin(admin.ModelAdmin):
    list_display = ["id", "text", "added", "active"]
    list_filter = ["active", "added"]
    actions = [make_active, make_inactive]


admin.site.register(Testimonial, TestimonialAdmin)



from setuptools import find_packages, setup

LONG_DESCRIPTION = """
.. image:: http://pinaxproject.com/pinax-design/patches/blank.svg
    :target: https://pypi.python.org/pypi/pinax-testimonials/

=================
Pinax Testimonials
=================

.. image:: https://img.shields.io/pypi/v/pinax-testimonials.svg
    :target: https://pypi.python.org/pypi/pinax-testimonials/
.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target: https://pypi.python.org/pypi/pinax-testimonials/

.. image:: https://img.shields.io/circleci/project/github/pinax/pinax-testimonials.svg
    :target: https://circleci.com/gh/pinax/pinax-testimonials
.. image:: https://img.shields.io/codecov/c/github/pinax/pinax-testimonials.svg
    :target: https://codecov.io/gh/pinax/pinax-testimonials
.. image:: https://img.shields.io/github/contributors/pinax/pinax-testimonials.svg
    :target: https://github.com/pinax/pinax-testimonials/graphs/contributors
.. image:: https://img.shields.io/github/issues-pr/pinax/pinax-testimonials.svg
    :target: https://github.com/pinax/pinax-testimonials/pulls
.. image:: https://img.shields.io/github/issues-pr-closed/pinax/pinax-testimonials.svg
    :target: https://github.com/pinax/pinax-testimonials/pulls?q=is%3Apr+is%3Aclosed

.. image:: http://slack.pinaxproject.com/badge.svg
    :target: http://slack.pinaxproject.com/
    
``pinax-testimonials`` is a well tested, documented, and proven solution for any site wanting to display testimonials.

Supported Django and Python Versions
------------------------------------

+-----------------+-----+-----+-----+-----+
| Django \ Python | 2.7 | 3.4 | 3.5 | 3.6 |
+=================+=====+=====+=====+=====+
| 1.11            |  *  |  *  |  *  |  *  |
+-----------------+-----+-----+-----+-----+
| 2.0             |     |  *  |  *  |  *  |
+-----------------+-----+-----+-----+-----+
"""

setup(
    author="Pinax Team",
    author_email="team@pinaxproject.com",
    description="a testimonials app",
    name="pinax-testimonials",
    long_description=LONG_DESCRIPTION,
    version="2.0.1",
    url="http://github.com/pinax/pinax-testimonials/",
    license="MIT",
    packages=find_packages(),
    package_data={
        "testimonials": []
    },
    test_suite="runtests.runtests",
    tests_require=[
        "dj-inmemorystorage>=1.4.0",
        "django-appconf>=1.0.1",
        "django-test-plus>=1.0.11",
        "mock>=1.3.0",
        "django-user-accounts>=1.3.1",
        "pinax-theme-bootstrap>=7.6.0",
    ],
    install_requires=[
        "django-appconf>=1.0.1"
    ],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Django",
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    zip_safe=False,
)



from django import template

from ..models import Testimonial

register = template.Library()


@register.simple_tag
def random_testimonials(number):
    return Testimonial.objects.filter(active=True).order_by("?")[:number]


@register.simple_tag
def random_testimonial():
    queryset = Testimonial.objects.filter(active=True).order_by("?")
    return queryset[0] if queryset else None


@register.simple_tag
def testimonials(number):
    return Testimonial.objects.filter(active=True).order_by("-added")[:number]
